| get_seafloor | R Documentation |
Get seafloor features at a spatial point
get_seafloor(lon, lat, seafloor, lat_range = 0.009009)
lon |
The longitude (decimal degrees; West coordinates are negative) of interest. This can be a single value or a vector of values. |
lat |
The latitude (decimal degrees; South coordinates are negative).
This must be the same length as |
seafloor |
A |
lat_range |
The range around the provided coordinate, expressed as a numeric representing degrees latitude, used to summarize seafloor features. The default represents 1 km north-south. |
A dataframe, with the number of rows equal to the length of lon, with the
following columns:
z Seafloor depth nearest to the coordinate.
zmin Minimum seafloor depth within lat_range of the coordinate.
zmax Maximum seafloor depth.
zsd Standard deviation of seafloor depth within lat_range.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.