View source: R/vessel_sun_angle.R
| vessel_sun_angle | R Documentation |
datetime, x, and yThis is essentially a convenient wrapper for suncalc::getSunlightPosition.
vessel_sun_angle(vessels, verbose = FALSE)
vessels |
A
|
verbose |
A Boolean; if |
A vector, the same length as the number of rows in vessels, with the
local vertical angle of the sun at each row.
data(ais_2019)
vessel_sun_angle(ais_2019)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.